|PyPI| |Docs| |Tests|

`Installation`_ | `Documentation`_ | `Tutorials`_ | `Preprint`_

|IMG1|


.. |PyPI| image:: https://img.shields.io/pypi/v/scarf.svg
         :target: https://pypi.org/project/scarf
.. |Docs| image:: https://readthedocs.org/projects/scarf/badge/?version=latest
         :target: https://scarf.readthedocs.io
.. |Tests| image:: https://circleci.com/gh/parashardhapola/scarf/tree/master.svg?style=svg
          :target: https://circleci.com/gh/parashardhapola/scarf/tree/master

.. |IMG1| image:: docs/source/logo_for_readme.png
         :width: 100%

Analyze large-scale (aka atlas-scale) single-cell genomics datasets with very low memory requirement.

.. _Documentation: http://scarf.rtfd.io
.. _Tutorials: https://scarf.readthedocs.io/en/stable/vignettes/basic_tutorial_scRNAseq.html
.. _Preprint: https://www.biorxiv.org/content/10.1101/2021.05.02.441899v1
.. _Installation: https://scarf.readthedocs.io/en/stable/install.html
